==> v0.1.53-snapshot.tar.gz: beteran-protobuf-rust/src/ss/member_bank_deposit.rs <==
const SUBJECT: &str = "bet.beteran.ss.member_bank_deposit";

pub const SUBJECT_CREATE_MEMBER_BANK_DEPOSIT: &str =
  const_format::concatcp!(SUBJECT, ".CreateMemberBankDeposit");
pub const SUBJECT_LIST_MEMBER_BANK_DEPOSITS: &str =
  const_format::concatcp!(SUBJECT, ".ListMemberBankDeposits");
pub const SUBJECT_GET_MEMBER_BANK_DEPOSIT: &str =
  const_format::concatcp!(SUBJECT, ".GetMemberBankDeposit");
pub const SUBJECT_UPDATE_MEMBER_BANK_DEPOSIT: &str =
  const_format::concatcp!(SUBJECT, ".UpdateMemberBankDeposit");
pub const SUBJECT_UPDATE_MEMBER_BANK_DEPOSIT_FOR_STATE: &str =
  const_format::concatcp!(SUBJECT, ".UpdateMemberBankDepositForState");
pub const SUBJECT_DELETE_MEMBER_BANK_DEPOSIT: &str =
  const_format::concatcp!(SUBJECT, ".DeleteMemberBankDeposit");

/// subject = bet.beteran.ss.member_bank_deposit.CreateMemberBankDeposit
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateMemberBankDepositRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<create_member_bank_deposit_request::Request>,
}
/// Nested message and enum types in `CreateMemberBankDepositRequest`.
pub mod create_member_bank_deposit_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub member_id: ::prost::alloc::string::String,
    #[prost(string, tag = "2")]
    pub name: ::prost::alloc::string::String,
    #[prost(uint32, tag = "3")]
    pub amount: u32,
    #[prost(string, optional, tag = "4")]
    pub memo: ::core::option::Option<::prost::alloc::string::String>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateMemberBankDepositResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<create_member_bank_deposit_response::Result>,
}
/// Nested message and enum types in `CreateMemberBankDepositResponse`.
pub mod create_member_bank_deposit_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_deposit:
      ::core::option::Option<crate::models::member_bank_deposit::MemberBankDeposit>,
  }
}
/// subject = bet.beteran.ss.member_bank_deposit.ListMemberBankDeposits
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListMemberBankDepositsRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<list_member_bank_deposits_request::Request>,
}
/// Nested message and enum types in `ListMemberBankDepositsRequest`.
pub mod list_member_bank_deposits_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(message, optional, tag = "1")]
    pub pagination: ::core::option::Option<crate::protobuf::pagination::Pagination>,
    #[prost(message, repeated, tag = "2")]
    pub sorts: ::prost::alloc::vec::Vec<crate::protobuf::pagination::Sort>,
    #[prost(message, optional, tag = "3")]
    pub search: ::core::option::Option<request::Search>,
  }
  /// Nested message and enum types in `Request`.
  pub mod request {
    #[derive(Clone, PartialEq, ::prost::Message)]
    pub struct Search {
      #[prost(string, optional, tag = "1")]
      pub member_id: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(string, optional, tag = "2")]
      pub name_like: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(uint32, optional, tag = "3")]
      pub amount: ::core::option::Option<u32>,
      #[prost(string, optional, tag = "4")]
      pub memo_like: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(
        enumeration = "crate::models::member_bank_deposit::MemberBankDepositState",
        optional,
        tag = "5"
      )]
      pub state: ::core::option::Option<i32>,
    }
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListMemberBankDepositsResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<list_member_bank_deposits_response::Result>,
}
/// Nested message and enum types in `ListMemberBankDepositsResponse`.
pub mod list_member_bank_deposits_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, repeated, tag = "1")]
    pub member_bank_deposits:
      ::prost::alloc::vec::Vec<crate::models::member_bank_deposit::MemberBankDeposit>,
  }
}
/// subject = bet.beteran.ss.member_bank_deposit.GetMemberBankDeposit
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetMemberBankDepositRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<get_member_bank_deposit_request::Request>,
}
/// Nested message and enum types in `GetMemberBankDepositRequest`.
pub mod get_member_bank_deposit_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetMemberBankDepositResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<get_member_bank_deposit_response::Result>,
}
/// Nested message and enum types in `GetMemberBankDepositResponse`.
pub mod get_member_bank_deposit_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_deposit:
      ::core::option::Option<crate::models::member_bank_deposit::MemberBankDeposit>,
  }
}
/// subject = bet.beteran.ss.member_bank_deposit.UpdateMemberBankDeposit
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankDepositRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<update_member_bank_deposit_request::Request>,
}
/// Nested message and enum types in `UpdateMemberBankDepositRequest`.
pub mod update_member_bank_deposit_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
    #[prost(string, tag = "3")]
    pub name: ::prost::alloc::string::String,
    #[prost(uint32, tag = "5")]
    pub amount: u32,
    #[prost(string, optional, tag = "7")]
    pub memo: ::core::option::Option<::prost::alloc::string::String>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankDepositResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<update_member_bank_deposit_response::Result>,
}
/// Nested message and enum types in `UpdateMemberBankDepositResponse`.
pub mod update_member_bank_deposit_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_deposit:
      ::core::option::Option<crate::models::member_bank_deposit::MemberBankDeposit>,
  }
}
/// subject = bet.beteran.ss.member_bank_deposit.UpdateMemberBankDepositForState
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankDepositForStateRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<update_member_bank_deposit_for_state_request::Request>,
}
/// Nested message and enum types in `UpdateMemberBankDepositForStateRequest`.
pub mod update_member_bank_deposit_for_state_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
    #[prost(
      enumeration = "crate::models::member_bank_deposit::MemberBankDepositState",
      tag = "2"
    )]
    pub state: i32,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankDepositForStateResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<update_member_bank_deposit_for_state_response::Result>,
}
/// Nested message and enum types in `UpdateMemberBankDepositForStateResponse`.
pub mod update_member_bank_deposit_for_state_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_deposit:
      ::core::option::Option<crate::models::member_bank_deposit::MemberBankDeposit>,
  }
}
/// subject = bet.beteran.ss.member_bank_deposit.DeleteMemberBankDeposit
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct DeleteMemberBankDepositRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<delete_member_bank_deposit_request::Request>,
}
/// Nested message and enum types in `DeleteMemberBankDepositRequest`.
pub mod delete_member_bank_deposit_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct DeleteMemberBankDepositResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<delete_member_bank_deposit_response::Result>,
}
/// Nested message and enum types in `DeleteMemberBankDepositResponse`.
pub mod delete_member_bank_deposit_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {}
}

==> v0.1.81-snapshot.tar.gz: beteran-protobuf-rust/src/ss/member_bank_deposit.rs <==
const SUBJECT: &str = "bet.beteran.ss.member_bank_deposit";
const EVENT_SUBJECT: &str = "bet.beteran.ss_event.member_bank_deposit";

pub const SUBJECT_CREATE_MEMBER_BANK_DEPOSIT: &str =
  const_format::concatcp!(SUBJECT, ".CreateMemberBankDeposit");
pub const SUBJECT_LIST_MEMBER_BANK_DEPOSITS: &str =
  const_format::concatcp!(SUBJECT, ".ListMemberBankDeposits");
pub const SUBJECT_GET_MEMBER_BANK_DEPOSIT: &str =
  const_format::concatcp!(SUBJECT, ".GetMemberBankDeposit");
pub const SUBJECT_UPDATE_MEMBER_BANK_DEPOSIT: &str =
  const_format::concatcp!(SUBJECT, ".UpdateMemberBankDeposit");
pub const SUBJECT_UPDATE_MEMBER_BANK_DEPOSIT_FOR_STATE: &str =
  const_format::concatcp!(SUBJECT, ".UpdateMemberBankDepositForState");
pub const SUBJECT_DELETE_MEMBER_BANK_DEPOSIT: &str =
  const_format::concatcp!(SUBJECT, ".DeleteMemberBankDeposit");

pub const EVENT_SUBJECT_AFTER_UPDATE_MEMBER_BANK_DEPOSIT_FOR_STATE: &str =
  const_format::concatcp!(EVENT_SUBJECT, ".AfterUpdateMemberBankDepositForState");

/// subject = bet.beteran.ss.member_bank_deposit.CreateMemberBankDeposit
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateMemberBankDepositRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<create_member_bank_deposit_request::Request>,
}
/// Nested message and enum types in `CreateMemberBankDepositRequest`.
pub mod create_member_bank_deposit_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub member_id: ::prost::alloc::string::String,
    #[prost(string, tag = "2")]
    pub name: ::prost::alloc::string::String,
    #[prost(uint32, tag = "3")]
    pub amount: u32,
    #[prost(string, optional, tag = "4")]
    pub memo: ::core::option::Option<::prost::alloc::string::String>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateMemberBankDepositResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<create_member_bank_deposit_response::Result>,
}
/// Nested message and enum types in `CreateMemberBankDepositResponse`.
pub mod create_member_bank_deposit_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_deposit:
      ::core::option::Option<crate::models::member_bank_deposit::MemberBankDepositModel>,
  }
}
/// subject = bet.beteran.ss.member_bank_deposit.ListMemberBankDeposits
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListMemberBankDepositsRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<list_member_bank_deposits_request::Request>,
}
/// Nested message and enum types in `ListMemberBankDepositsRequest`.
pub mod list_member_bank_deposits_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(message, optional, tag = "1")]
    pub pagination: ::core::option::Option<crate::protobuf::pagination::Pagination>,
    #[prost(message, repeated, tag = "2")]
    pub sorts: ::prost::alloc::vec::Vec<crate::protobuf::pagination::Sort>,
    #[prost(message, optional, tag = "3")]
    pub search: ::core::option::Option<request::Search>,
  }
  /// Nested message and enum types in `Request`.
  pub mod request {
    #[derive(Clone, PartialEq, ::prost::Message)]
    pub struct Search {
      #[prost(string, optional, tag = "1")]
      pub member_id: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(string, optional, tag = "2")]
      pub name_like: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(uint32, optional, tag = "3")]
      pub amount: ::core::option::Option<u32>,
      #[prost(string, optional, tag = "4")]
      pub memo_like: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(
        enumeration = "crate::models::member_bank_deposit::MemberBankDepositState",
        optional,
        tag = "5"
      )]
      pub state: ::core::option::Option<i32>,
    }
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListMemberBankDepositsResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<list_member_bank_deposits_response::Result>,
}
/// Nested message and enum types in `ListMemberBankDepositsResponse`.
pub mod list_member_bank_deposits_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, repeated, tag = "1")]
    pub member_bank_deposits:
      ::prost::alloc::vec::Vec<crate::models::member_bank_deposit::MemberBankDepositModel>,
  }
}
/// subject = bet.beteran.ss.member_bank_deposit.GetMemberBankDeposit
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetMemberBankDepositRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<get_member_bank_deposit_request::Request>,
}
/// Nested message and enum types in `GetMemberBankDepositRequest`.
pub mod get_member_bank_deposit_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetMemberBankDepositResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<get_member_bank_deposit_response::Result>,
}
/// Nested message and enum types in `GetMemberBankDepositResponse`.
pub mod get_member_bank_deposit_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_deposit:
      ::core::option::Option<crate::models::member_bank_deposit::MemberBankDepositModel>,
  }
}
/// subject = bet.beteran.ss.member_bank_deposit.UpdateMemberBankDeposit
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankDepositRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<update_member_bank_deposit_request::Request>,
}
/// Nested message and enum types in `UpdateMemberBankDepositRequest`.
pub mod update_member_bank_deposit_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
    #[prost(string, tag = "3")]
    pub name: ::prost::alloc::string::String,
    #[prost(uint32, tag = "5")]
    pub amount: u32,
    #[prost(string, optional, tag = "7")]
    pub memo: ::core::option::Option<::prost::alloc::string::String>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankDepositResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<update_member_bank_deposit_response::Result>,
}
/// Nested message and enum types in `UpdateMemberBankDepositResponse`.
pub mod update_member_bank_deposit_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_deposit:
      ::core::option::Option<crate::models::member_bank_deposit::MemberBankDepositModel>,
  }
}
/// subject = bet.beteran.ss.member_bank_deposit.UpdateMemberBankDepositForState
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankDepositForStateRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<update_member_bank_deposit_for_state_request::Request>,
}
/// Nested message and enum types in `UpdateMemberBankDepositForStateRequest`.
pub mod update_member_bank_deposit_for_state_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
    #[prost(
      enumeration = "crate::models::member_bank_deposit::MemberBankDepositState",
      tag = "2"
    )]
    pub state: i32,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankDepositForStateResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<update_member_bank_deposit_for_state_response::Result>,
}
/// Nested message and enum types in `UpdateMemberBankDepositForStateResponse`.
pub mod update_member_bank_deposit_for_state_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_deposit:
      ::core::option::Option<crate::models::member_bank_deposit::MemberBankDepositModel>,
  }
}
/// subject = bet.beteran.ss.member_bank_deposit.DeleteMemberBankDeposit
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct DeleteMemberBankDepositRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<delete_member_bank_deposit_request::Request>,
}
/// Nested message and enum types in `DeleteMemberBankDepositRequest`.
pub mod delete_member_bank_deposit_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct DeleteMemberBankDepositResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<delete_member_bank_deposit_response::Result>,
}
/// Nested message and enum types in `DeleteMemberBankDepositResponse`.
pub mod delete_member_bank_deposit_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {}
}

/// subject = bet.beteran.ss_event.member_bank_deposit.AfterUpdateMemberBankDepositForState
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct AfterUpdateMemberBankDepositForState {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub event: ::core::option::Option<after_update_member_bank_deposit_for_state::Event>,
}
/// Nested message and enum types in `AfterUpdateMemberBankDepositForState`.
pub mod after_update_member_bank_deposit_for_state {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Event {
    #[prost(message, optional, tag = "1")]
    pub member_bank_deposit:
      ::core::option::Option<crate::models::member_bank_deposit::MemberBankDepositModel>,
  }
}
